# Generated by roxygen2: do not edit by hand

S3method(as_g6_combo,g6_combo)
S3method(as_g6_combo,list)
S3method(as_g6_combos,data.frame)
S3method(as_g6_combos,g6_combos)
S3method(as_g6_combos,list)
S3method(as_g6_data,g6_data)
S3method(as_g6_data,list)
S3method(as_g6_edge,g6_edge)
S3method(as_g6_edge,list)
S3method(as_g6_edges,data.frame)
S3method(as_g6_edges,g6_edges)
S3method(as_g6_edges,list)
S3method(as_g6_node,g6_node)
S3method(as_g6_node,list)
S3method(as_g6_nodes,data.frame)
S3method(as_g6_nodes,g6_nodes)
S3method(as_g6_nodes,list)
S3method(as_g6_port,g6_port)
S3method(as_g6_port,list)
S3method(as_g6_ports,g6_ports)
S3method(as_g6_ports,list)
S3method(validate_element,g6_combo)
S3method(validate_element,g6_edge)
S3method(validate_element,g6_element)
S3method(validate_element,g6_node)
S3method(validate_elements,g6_combos)
S3method(validate_elements,g6_edges)
S3method(validate_elements,g6_nodes)
S3method(validate_port,g6_port)
S3method(validate_ports,g6_ports)
S3method(validate_ports,list)
export(JS)
export(animation_config)
export(antv_dagre_layout)
export(as_g6_combo)
export(as_g6_combos)
export(as_g6_data)
export(as_g6_edge)
export(as_g6_edges)
export(as_g6_node)
export(as_g6_nodes)
export(as_g6_port)
export(as_g6_ports)
export(auto_adapt_label)
export(auto_fit_config)
export(background)
export(brush_select)
export(bubble_sets)
export(canvas_config)
export(circular_layout)
export(click_select)
export(collapse_expand)
export(combo_combined_layout)
export(combo_options)
export(compact_box_layout)
export(concentric_layout)
export(context_menu)
export(create_edge)
export(d3_force_layout)
export(dagre_layout)
export(dendrogram_layout)
export(drag_canvas)
export(drag_element)
export(drag_element_force)
export(edge_bundling)
export(edge_filter_lens)
export(edge_options)
export(edge_style_options)
export(fish_eye)
export(fix_element_size)
export(focus_element)
export(force_atlas2_layout)
export(fruchterman_layout)
export(fullscreen)
export(g6)
export(g6Output)
export(g6_add_combos)
export(g6_add_data)
export(g6_add_edges)
export(g6_add_nodes)
export(g6_add_plugin)
export(g6_behaviors)
export(g6_canvas_resize)
export(g6_collapse_combo)
export(g6_collapse_options)
export(g6_combo)
export(g6_combos)
export(g6_data)
export(g6_edge)
export(g6_edges)
export(g6_expand_combo)
export(g6_fit_center)
export(g6_focus_combos)
export(g6_focus_edges)
export(g6_focus_nodes)
export(g6_get_combos)
export(g6_get_edges)
export(g6_get_input_ports)
export(g6_get_nodes)
export(g6_get_output_ports)
export(g6_get_ports)
export(g6_hide_combos)
export(g6_hide_edges)
export(g6_hide_elements)
export(g6_hide_nodes)
export(g6_igraph)
export(g6_input_port)
export(g6_layout)
export(g6_node)
export(g6_nodes)
export(g6_options)
export(g6_output)
export(g6_output_port)
export(g6_plugins)
export(g6_port)
export(g6_ports)
export(g6_proxy)
export(g6_remove_combos)
export(g6_remove_edges)
export(g6_remove_nodes)
export(g6_set_combos)
export(g6_set_data)
export(g6_set_edges)
export(g6_set_nodes)
export(g6_set_options)
export(g6_set_theme)
export(g6_show_combos)
export(g6_show_edges)
export(g6_show_elements)
export(g6_show_nodes)
export(g6_update_behavior)
export(g6_update_combos)
export(g6_update_edges)
export(g6_update_layout)
export(g6_update_nodes)
export(g6_update_plugin)
export(g6_update_ports)
export(grid_line)
export(history)
export(hover_activate)
export(hull)
export(is_g6_collapse_options)
export(is_g6_combo)
export(is_g6_combos)
export(is_g6_data)
export(is_g6_edge)
export(is_g6_edges)
export(is_g6_node)
export(is_g6_nodes)
export(is_g6_port)
export(is_g6_ports)
export(lasso_select)
export(legend)
export(minimap)
export(node_options)
export(node_style_options)
export(optimize_viewport_transform)
export(radial_layout)
export(renderG6)
export(render_g6)
export(scroll_canvas)
export(set_g6_max_collapse_depth)
export(snapline)
export(timebar)
export(toolbar)
export(tooltips)
export(validate_edges_ports)
export(validate_element)
export(validate_elements)
export(validate_port)
export(validate_ports)
export(watermark)
export(zoom_canvas)
import(htmlwidgets)
importFrom(stats,setNames)
