# g6 function creates proper htmlwidget

    Code
      g6(iconsUrl = NULL)
    Condition
      Error in `g6()`:
      ! !is.null(iconsUrl) is not TRUE
    Code
      g6(nodes = data.frame(), jsonUrl = "https://assets.antv.antgroup.com/g6/cluster.json")
    Condition
      Error in `g6()`:
      ! Can't use jsonUrl` argument at the same time as `nodes`, `edges`, and `combos`.

